@@ -37,22 +37,26 @@ mod delay;
 mod error;
 mod forwarder;
 mod lease;
+mod metadata;
 mod monotonic;
 mod protocols;
 mod remote_forwarder;
+mod system;
 mod unique;
 
 pub use delay::*;
 pub use error::*;
 pub use forwarder::*;
 pub use lease::*;
+pub use metadata::*;
 pub use ockam_core::compat;
 pub use ockam_core::println;
 pub use ockam_core::worker;
 pub use ockam_core::AsyncTryClone;
-pub use ockam_entity::*;
+pub use ockam_identity::*;
 pub use protocols::*;
 pub use remote_forwarder::*;
+pub use system::*;
 pub use unique::*;
 
 pub mod channel;
@@ -74,7 +78,7 @@ pub use ockam_core::route;
 pub use ockam_key_exchange_xx::XXNewKeyExchanger;
 
 #[cfg(feature = "ockam_vault")]
-pub use ockam_vault_sync_core::{Vault, VaultSync};
+pub use ockam_vault_sync_core::Vault;
 
 #[cfg(feature = "ockam_vault")]
 pub use ockam_vault::SoftwareVault;
