@@ -2,7 +2,8 @@
 
 mod behavior;
 pub use behavior::{
-    BehaviorHook, PipeBehavior, PipeModifier, ReceiverConfirm, ReceiverOrdering, SenderConfirm,
+    BehaviorHook, HandshakeInit, PipeBehavior, PipeModifier, ReceiverConfirm, ReceiverOrdering,
+    SenderConfirm,
 };
 
 mod listener;
@@ -72,7 +73,7 @@ pub async fn connect_dynamic(ctx: &mut Context, listener: Route) -> Result<Addre
         ctx,
         addr.clone(),
         int_addr.clone(),
-        listener,
+        Some(listener),
         PipeBehavior::empty(),
     )
     .await?;
